@@ -13,15 +13,22 @@ has collection => (
     required => 1,
 );
 
+has count => (
+    is => 'rwp',
+);
+
+sub BUILD {
+    my $self = shift;
+    $self->_set_count(scalar @{$self->collection});
+}
+
 sub match_all {
     my $self = shift;
-
     return [map { $_->match } @{$self->collection}];
 }
 
 sub captures_all {
     my $self = shift;
-
     return [map { $_->captures } @{$self->collection}];
 }
 
